summaryrefslogtreecommitdiff
path: root/lib/libc/stdio/fsetpos.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libc/stdio/fsetpos.c')
-rw-r--r--lib/libc/stdio/fsetpos.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/libc/stdio/fsetpos.c b/lib/libc/stdio/fsetpos.c
index c6fae71d7b0..bc538ee4f7e 100644
--- a/lib/libc/stdio/fsetpos.c
+++ b/lib/libc/stdio/fsetpos.c
@@ -35,18 +35,18 @@
*/
#if defined(LIBC_SCCS) && !defined(lint)
-static char rcsid[] = "$OpenBSD: fsetpos.c,v 1.2 1996/08/19 08:32:47 tholo Exp $";
+static char rcsid[] = "$OpenBSD: fsetpos.c,v 1.3 2000/02/21 22:11:22 millert Exp $";
#endif /* LIBC_SCCS and not lint */
#include <stdio.h>
/*
* fsetpos: like fseek.
*/
int
fsetpos(iop, pos)
FILE *iop;
const fpos_t *pos;
{
- return (fseek(iop, (long)*pos, SEEK_SET));
+ return (fseeko(iop, (off_t)*pos, SEEK_SET));
}
@@ -35,18 +35,18 @@
#include <stdio.h>
/*
- * fsetpos: like fseek.
+ * fsetpos: like fseeko.
*/
int